@@ -1,7 +1,8 @@
 from typing import List
+import itertools
 
 def flattened_list_of_lists(list_of_lists: List[List], unique: bool = False) -> List:
-    flat = [item for sublist in list_of_lists for item in sublist]
+    flat = list(itertools.chain.from_iterable(list_of_lists))
 
     if unique:
         flat = list(set(flat))
@@ -19,7 +20,6 @@ def all_indxs_in_lst(lst: List, value) -> List[int]:
             break
     return idxs
 
-
 if __name__ == "__main__":
     import random as rnd
     l_o_l = [[x for x in range(rnd.randint(5, 10))] for y in range(rnd.randint(5, 10))]
